==> qtjambi-datavisualization-6.2.9-sources.jar: io/qt/datavis/Q3DInputHandler.java <==
package io.qt.datavis;


/**
 * <p>Basic wheel mouse based input handler</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/q3dinputhandler.html">Q3DInputHandler</a></p>
 */
public class Q3DInputHandler extends io.qt.datavis.QAbstract3DInputHandler
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(Q3DInputHandler.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/q3dinputhandler.html#rotationEnabled-prop">Q3DInputHandler::rotationEnabledChanged(bool)</a></p>
     */
    @io.qt.QtPropertyNotify(name="rotationEnabled")
    public final Signal1<@io.qt.QtPrimitiveType Boolean> rotationEnabledChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/q3dinputhandler.html#selectionEnabled-prop">Q3DInputHandler::selectionEnabledChanged(bool)</a></p>
     */
    @io.qt.QtPropertyNotify(name="selectionEnabled")
    public final Signal1<@io.qt.QtPrimitiveType Boolean> selectionEnabledChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/q3dinputhandler.html#zoomAtTargetEnabled-prop">Q3DInputHandler::zoomAtTargetEnabledChanged(bool)</a></p>
     */
    @io.qt.QtPropertyNotify(name="zoomAtTargetEnabled")
    public final Signal1<@io.qt.QtPrimitiveType Boolean> zoomAtTargetEnabledChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/q3dinputhandler.html#zoomEnabled-prop">Q3DInputHandler::zoomEnabledChanged(bool)</a></p>
     */
    @io.qt.QtPropertyNotify(name="zoomEnabled")
    public final Signal1<@io.qt.QtPrimitiveType Boolean> zoomEnabledChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #Q3DInputHandler(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public Q3DInputHandler() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/q3dinputhandler.html#Q3DInputHandler">Q3DInputHandler::Q3DInputHandler(QObject*)</a></p>
     */
    public Q3DInputHandler(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(Q3DInputHandler instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/q3dinputhandler.html#rotationEnabled-prop">Q3DInputHandler::isRotationEnabled()const</a></p>
     */
    @io.qt.QtPropertyReader(name="rotationEnabled")
    @io.qt.QtUninvokable
    public final boolean isRotationEnabled(){
        return isRotationEnabled_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isRotationEnabled_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/q3dinputhandler.html#selectionEnabled-prop">Q3DInputHandler::isSelectionEnabled()const</a></p>
     */
    @io.qt.QtPropertyReader(name="selectionEnabled")
    @io.qt.QtUninvokable
    public final boolean isSelectionEnabled(){
        return isSelectionEnabled_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isSelectionEnabled_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/q3dinputhandler.html#zoomAtTargetEnabled-prop">Q3DInputHandler::isZoomAtTargetEnabled()const</a></p>
     */
    @io.qt.QtPropertyReader(name="zoomAtTargetEnabled")
    @io.qt.QtUninvokable
    public final boolean isZoomAtTargetEnabled(){
        return isZoomAtTargetEnabled_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isZoomAtTargetEnabled_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/q3dinputhandler.html#zoomEnabled-prop">Q3DInputHandler::isZoomEnabled()const</a></p>
     */
    @io.qt.QtPropertyReader(name="zoomEnabled")
    @io.qt.QtUninvokable
    public final boolean isZoomEnabled(){
        return isZoomEnabled_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isZoomEnabled_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/q3dinputhandler.html#rotationEnabled-prop">Q3DInputHandler::setRotationEnabled(bool)</a></p>
     */
    @io.qt.QtPropertyWriter(name="rotationEnabled")
    @io.qt.QtUninvokable
    public final void setRotationEnabled(boolean enable){
        setRotationEnabled_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), enable);
    }
    
    @io.qt.QtUninvokable
    private native void setRotationEnabled_native_bool(long __this__nativeId, boolean enable);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/q3dinputhandler.html#selectionEnabled-prop">Q3DInputHandler::setSelectionEnabled(bool)</a></p>
     */
    @io.qt.QtPropertyWriter(name="selectionEnabled")
    @io.qt.QtUninvokable
    public final void setSelectionEnabled(boolean enable){
        setSelectionEnabled_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), enable);
    }
    
    @io.qt.QtUninvokable
    private native void setSelectionEnabled_native_bool(long __this__nativeId, boolean enable);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/q3dinputhandler.html#zoomAtTargetEnabled-prop">Q3DInputHandler::setZoomAtTargetEnabled(bool)</a></p>
     */
    @io.qt.QtPropertyWriter(name="zoomAtTargetEnabled")
    @io.qt.QtUninvokable
    public final void setZoomAtTargetEnabled(boolean enable){
        setZoomAtTargetEnabled_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), enable);
    }
    
    @io.qt.QtUninvokable
    private native void setZoomAtTargetEnabled_native_bool(long __this__nativeId, boolean enable);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/q3dinputhandler.html#zoomEnabled-prop">Q3DInputHandler::setZoomEnabled(bool)</a></p>
     */
    @io.qt.QtPropertyWriter(name="zoomEnabled")
    @io.qt.QtUninvokable
    public final void setZoomEnabled(boolean enable){
        setZoomEnabled_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), enable);
    }
    
    @io.qt.QtUninvokable
    private native void setZoomEnabled_native_bool(long __this__nativeId, boolean enable);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qabstract3dinputhandler.html#mouseMoveEvent">QAbstract3DInputHandler::mouseMoveEvent(QMouseEvent*,QPoint)</a></p>
     */
    @io.qt.QtUninvokable
    public void mouseMoveEvent(io.qt.gui.QMouseEvent event, io.qt.core.QPoint mousePos){
        mouseMoveEvent_native_QMouseEvent_ptr_cref_QPoint(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(event), QtJambi_LibraryUtilities.internal.checkedNativeId(mousePos));
    }
    
    @io.qt.QtUninvokable
    private native void mouseMoveEvent_native_QMouseEvent_ptr_cref_QPoint(long __this__nativeId, long event, long mousePos);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qabstract3dinputhandler.html#mousePressEvent">QAbstract3DInputHandler::mousePressEvent(QMouseEvent*,QPoint)</a></p>
     */
    @io.qt.QtUninvokable
    public void mousePressEvent(io.qt.gui.QMouseEvent event, io.qt.core.QPoint mousePos){
        mousePressEvent_native_QMouseEvent_ptr_cref_QPoint(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(event), QtJambi_LibraryUtilities.internal.checkedNativeId(mousePos));
    }
    
    @io.qt.QtUninvokable
    private native void mousePressEvent_native_QMouseEvent_ptr_cref_QPoint(long __this__nativeId, long event, long mousePos);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qabstract3dinputhandler.html#mouseReleaseEvent">QAbstract3DInputHandler::mouseReleaseEvent(QMouseEvent*,QPoint)</a></p>
     */
    @io.qt.QtUninvokable
    public void mouseReleaseEvent(io.qt.gui.QMouseEvent event, io.qt.core.QPoint mousePos){
        mouseReleaseEvent_native_QMouseEvent_ptr_cref_QPoint(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(event), QtJambi_LibraryUtilities.internal.checkedNativeId(mousePos));
    }
    
    @io.qt.QtUninvokable
    private native void mouseReleaseEvent_native_QMouseEvent_ptr_cref_QPoint(long __this__nativeId, long event, long mousePos);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qabstract3dinputhandler.html#wheelEvent">QAbstract3DInputHandler::wheelEvent(QWheelEvent*)</a></p>
     */
    @io.qt.QtUninvokable
    public void wheelEvent(io.qt.gui.QWheelEvent event){
        wheelEvent_native_QWheelEvent_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(event));
    }
    
    @io.qt.QtUninvokable
    private native void wheelEvent_native_QWheelEvent_ptr(long __this__nativeId, long event);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected Q3DInputHandler(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected Q3DInputHandler(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(Q3DInputHandler instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-datavisualization-6.3.0-sources.jar: io/qt/datavis/Q3DInputHandler.java <==
package io.qt.datavis;


/**
 * <p>Basic wheel mouse based input handler</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/q3dinputhandler.html">Q3DInputHandler</a></p>
 */
public class Q3DInputHandler extends io.qt.datavis.QAbstract3DInputHandler
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(Q3DInputHandler.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/q3dinputhandler.html#rotationEnabled-prop">Q3DInputHandler::rotationEnabledChanged(bool)</a></p>
     */
    @io.qt.QtPropertyNotify(name="rotationEnabled")
    public final Signal1<@io.qt.QtPrimitiveType Boolean> rotationEnabledChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/q3dinputhandler.html#selectionEnabled-prop">Q3DInputHandler::selectionEnabledChanged(bool)</a></p>
     */
    @io.qt.QtPropertyNotify(name="selectionEnabled")
    public final Signal1<@io.qt.QtPrimitiveType Boolean> selectionEnabledChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/q3dinputhandler.html#zoomAtTargetEnabled-prop">Q3DInputHandler::zoomAtTargetEnabledChanged(bool)</a></p>
     */
    @io.qt.QtPropertyNotify(name="zoomAtTargetEnabled")
    public final Signal1<@io.qt.QtPrimitiveType Boolean> zoomAtTargetEnabledChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/q3dinputhandler.html#zoomEnabled-prop">Q3DInputHandler::zoomEnabledChanged(bool)</a></p>
     */
    @io.qt.QtPropertyNotify(name="zoomEnabled")
    public final Signal1<@io.qt.QtPrimitiveType Boolean> zoomEnabledChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #Q3DInputHandler(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public Q3DInputHandler() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/q3dinputhandler.html#Q3DInputHandler">Q3DInputHandler::Q3DInputHandler(QObject*)</a></p>
     */
    public Q3DInputHandler(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(Q3DInputHandler instance, io.qt.core.QObject parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/q3dinputhandler.html#rotationEnabled-prop">Q3DInputHandler::isRotationEnabled()const</a></p>
     */
    @io.qt.QtPropertyReader(name="rotationEnabled")
    @io.qt.QtUninvokable
    public final boolean isRotationEnabled(){
        return isRotationEnabled_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isRotationEnabled_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/q3dinputhandler.html#selectionEnabled-prop">Q3DInputHandler::isSelectionEnabled()const</a></p>
     */
    @io.qt.QtPropertyReader(name="selectionEnabled")
    @io.qt.QtUninvokable
    public final boolean isSelectionEnabled(){
        return isSelectionEnabled_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isSelectionEnabled_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/q3dinputhandler.html#zoomAtTargetEnabled-prop">Q3DInputHandler::isZoomAtTargetEnabled()const</a></p>
     */
    @io.qt.QtPropertyReader(name="zoomAtTargetEnabled")
    @io.qt.QtUninvokable
    public final boolean isZoomAtTargetEnabled(){
        return isZoomAtTargetEnabled_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isZoomAtTargetEnabled_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/q3dinputhandler.html#zoomEnabled-prop">Q3DInputHandler::isZoomEnabled()const</a></p>
     */
    @io.qt.QtPropertyReader(name="zoomEnabled")
    @io.qt.QtUninvokable
    public final boolean isZoomEnabled(){
        return isZoomEnabled_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isZoomEnabled_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/q3dinputhandler.html#rotationEnabled-prop">Q3DInputHandler::setRotationEnabled(bool)</a></p>
     */
    @io.qt.QtPropertyWriter(name="rotationEnabled")
    @io.qt.QtUninvokable
    public final void setRotationEnabled(boolean enable){
        setRotationEnabled_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), enable);
    }
    
    @io.qt.QtUninvokable
    private native void setRotationEnabled_native_bool(long __this__nativeId, boolean enable);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/q3dinputhandler.html#selectionEnabled-prop">Q3DInputHandler::setSelectionEnabled(bool)</a></p>
     */
    @io.qt.QtPropertyWriter(name="selectionEnabled")
    @io.qt.QtUninvokable
    public final void setSelectionEnabled(boolean enable){
        setSelectionEnabled_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), enable);
    }
    
    @io.qt.QtUninvokable
    private native void setSelectionEnabled_native_bool(long __this__nativeId, boolean enable);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/q3dinputhandler.html#zoomAtTargetEnabled-prop">Q3DInputHandler::setZoomAtTargetEnabled(bool)</a></p>
     */
    @io.qt.QtPropertyWriter(name="zoomAtTargetEnabled")
    @io.qt.QtUninvokable
    public final void setZoomAtTargetEnabled(boolean enable){
        setZoomAtTargetEnabled_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), enable);
    }
    
    @io.qt.QtUninvokable
    private native void setZoomAtTargetEnabled_native_bool(long __this__nativeId, boolean enable);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/q3dinputhandler.html#zoomEnabled-prop">Q3DInputHandler::setZoomEnabled(bool)</a></p>
     */
    @io.qt.QtPropertyWriter(name="zoomEnabled")
    @io.qt.QtUninvokable
    public final void setZoomEnabled(boolean enable){
        setZoomEnabled_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), enable);
    }
    
    @io.qt.QtUninvokable
    private native void setZoomEnabled_native_bool(long __this__nativeId, boolean enable);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qabstract3dinputhandler.html#mouseMoveEvent">QAbstract3DInputHandler::mouseMoveEvent(QMouseEvent*,QPoint)</a></p>
     */
    @io.qt.QtUninvokable
    public void mouseMoveEvent(io.qt.gui.QMouseEvent event, io.qt.core.QPoint mousePos){
        mouseMoveEvent_native_QMouseEvent_ptr_cref_QPoint(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(event), QtJambi_LibraryUtilities.internal.checkedNativeId(mousePos));
    }
    
    @io.qt.QtUninvokable
    private native void mouseMoveEvent_native_QMouseEvent_ptr_cref_QPoint(long __this__nativeId, long event, long mousePos);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qabstract3dinputhandler.html#mousePressEvent">QAbstract3DInputHandler::mousePressEvent(QMouseEvent*,QPoint)</a></p>
     */
    @io.qt.QtUninvokable
    public void mousePressEvent(io.qt.gui.QMouseEvent event, io.qt.core.QPoint mousePos){
        mousePressEvent_native_QMouseEvent_ptr_cref_QPoint(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(event), QtJambi_LibraryUtilities.internal.checkedNativeId(mousePos));
    }
    
    @io.qt.QtUninvokable
    private native void mousePressEvent_native_QMouseEvent_ptr_cref_QPoint(long __this__nativeId, long event, long mousePos);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qabstract3dinputhandler.html#mouseReleaseEvent">QAbstract3DInputHandler::mouseReleaseEvent(QMouseEvent*,QPoint)</a></p>
     */
    @io.qt.QtUninvokable
    public void mouseReleaseEvent(io.qt.gui.QMouseEvent event, io.qt.core.QPoint mousePos){
        mouseReleaseEvent_native_QMouseEvent_ptr_cref_QPoint(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(event), QtJambi_LibraryUtilities.internal.checkedNativeId(mousePos));
    }
    
    @io.qt.QtUninvokable
    private native void mouseReleaseEvent_native_QMouseEvent_ptr_cref_QPoint(long __this__nativeId, long event, long mousePos);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qabstract3dinputhandler.html#wheelEvent">QAbstract3DInputHandler::wheelEvent(QWheelEvent*)</a></p>
     */
    @io.qt.QtUninvokable
    public void wheelEvent(io.qt.gui.QWheelEvent event){
        wheelEvent_native_QWheelEvent_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(event));
    }
    
    @io.qt.QtUninvokable
    private native void wheelEvent_native_QWheelEvent_ptr(long __this__nativeId, long event);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected Q3DInputHandler(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected Q3DInputHandler(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(Q3DInputHandler instance, QDeclarativeConstructor constructor);
    
}
